@@ -1,6 +1,7 @@
 package org.gcube.portlets.user.td.gwtservice.shared.tr.paging;
 
 import java.io.Serializable;
+import java.util.ArrayList;
 
 /**
  * 
@@ -14,19 +15,18 @@ public class CodelistPagingLoadConfig implements Serializable {
 
 	protected int offset;
 	protected int limit;
-	protected Direction direction;
+	protected ArrayList<OrderInfo> listOrderInfo;
 	protected String filter;
 	
 	public CodelistPagingLoadConfig(){}
 	
-	public CodelistPagingLoadConfig(int offset, int limit, Direction direction, String filter){
+	public CodelistPagingLoadConfig(int offset, int limit, ArrayList<OrderInfo> listOrderInfo, String filter){
 		this.offset=offset;
 		this.limit=limit;
-		this.direction=direction;
+		this.listOrderInfo=listOrderInfo;
 		this.filter=filter;
 	}
-	
-	
+
 	public int getOffset() {
 		return offset;
 	}
@@ -43,12 +43,12 @@ public class CodelistPagingLoadConfig implements Serializable {
 		this.limit = limit;
 	}
 
-	public Direction getDirection() {
-		return direction;
+	public ArrayList<OrderInfo> getListOrderInfo() {
+		return listOrderInfo;
 	}
 
-	public void setDirection(Direction direction) {
-		this.direction = direction;
+	public void setListOrderInfo(ArrayList<OrderInfo> listOrderInfo) {
+		this.listOrderInfo = listOrderInfo;
 	}
 
 	public String getFilter() {
@@ -62,8 +62,9 @@ public class CodelistPagingLoadConfig implements Serializable {
 	@Override
 	public String toString() {
 		return "CodelistPagingLoadConfig [offset=" + offset + ", limit="
-				+ limit + ", direction=" + direction + ", filter=" + filter
-				+ "]";
+				+ limit + ", listOrderInfo=" + listOrderInfo + ", filter="
+				+ filter + "]";
 	}
-
+	
+	
 }
